@@ -189,10 +189,11 @@ def declare_datatype(datatype, iri, parser, unparser):
   storid = _universal_abbrev(iri)
   from owlready2 import WORLDS
   for world in WORLDS:
-    world.graph.execute("INSERT INTO resources VALUES (?,?)", (storid, iri))
-    if world.graph._abbreviate_d:
-      world.graph._abbreviate_d  [iri]    = storid
-      world.graph._unabbreviate_d[storid] = iri
+    if not world.graph.read_only:
+      world.graph.execute("INSERT OR IGNORE INTO resources VALUES (?,?)", (storid, iri))
+      #if world.graph._abbreviate_d:
+      #  world.graph._abbreviate_d  [iri]    = storid
+      #  world.graph._unabbreviate_d[storid] = iri
       
   _universal_datatype_2_abbrev         [datatype] =  storid
   _universal_datatype_2_abbrev_unparser[datatype] = (storid, unparser)
@@ -200,6 +201,12 @@ def declare_datatype(datatype, iri, parser, unparser):
   _universal_abbrev_2_datatype_parser  [storid]   = (datatype, parser)
   return storid
 
+def define_datatype_in_ontology(datatype, iri, ontology):
+  storid = ontology.world._abbreviate(iri)
+  ontology._add_obj_triple_spo(storid, rdf_type, rdfs_datatype)
+  
+
+
 owl_alldisjointproperties = _universal_abbrev("http://www.w3.org/2002/07/owl#AllDisjointProperties")
 owl_equivalentproperty    = _universal_abbrev("http://www.w3.org/2002/07/owl#equivalentProperty")
 owl_equivalentindividual  = _universal_abbrev("http://www.w3.org/2002/07/owl#sameAs")
