@@ -230,7 +230,7 @@ class EntityClass(type):
       type.__setattr__(Class, "is_a", CallbackList(value, Class, Class.__class__._class_is_a_changed))
       Class._class_is_a_changed(old)
       return
-      
+
     type.__setattr__(Class, attr, value)
     
   def _class_is_a_changed(Class, old):
@@ -248,8 +248,9 @@ class EntityClass(type):
       Class.__bases__ = bases
     else:
       if   isinstance(Class, ThingClass):
-        Class.__bases__ = (Thing,)
-        list.insert(Class.is_a, 0, Thing)
+        if not Class is Thing:
+          Class.__bases__ = (Thing,)
+          list.insert(Class.is_a, 0, Thing)
       elif isinstance(Class, ObjectPropertyClass):
         Class.__bases__ = (ObjectProperty,)
         list.insert(Class.is_a, 0, ObjectProperty)
@@ -259,7 +260,10 @@ class EntityClass(type):
         
     for base in new - old:
       if isinstance(base, Construct):
-        base = base._set_ontology_copy_if_needed(Class.namespace.ontology, Class.is_a)
+        if Class is Thing:
+          base = base._set_ontology_copy_if_needed(CURRENT_NAMESPACES.get()[-1].ontology, Class.is_a)
+        else:
+          base = base._set_ontology_copy_if_needed(Class.namespace.ontology, Class.is_a)
       if not LOADING: Class._add_is_a_triple(base)
       
   def disjoints(Class):
@@ -293,6 +297,24 @@ class EntityClass(type):
       Class._fill_descendants(s, include_self, only_loaded, Class.namespace.world, Class.namespace.ontology)
     return s
   
+  # def descendants2(Class, include_self = True, only_loaded = False, world = None):
+  #   if (Class.namespace.world is owl_world) and (world is None):
+  #     import owlready2
+  #     world = owlready2.default_world
+  #   else:
+  #     world = Class.namespace.world
+
+  #   if only_loaded:
+  #     if include_self:
+  #       return set(world.prepare_sparql("""SELECT ?c { ?c (rdfs:subClassOf|owl:equivalentClass|^owl:equivalentClass)* ?? . FILTER(ISIRI(?c)) . FILTER(LOADED(?c)) }""").execute_flat((Class,)))
+  #     else:
+  #       return set(world.prepare_sparql("""SELECT ?c { ?c (rdfs:subClassOf|owl:equivalentClass|^owl:equivalentClass)*/rdfs:subClassOf ?? . FILTER(ISIRI(?c)) . FILTER(LOADED(?c)) }""").execute_flat((Class,)))
+  #   else:
+  #     if include_self:
+  #       return set(world.prepare_sparql("""SELECT ?c { ?c (rdfs:subClassOf|owl:equivalentClass|^owl:equivalentClass)* ?? . FILTER(ISIRI(?c)) }""").execute_flat((Class,)))
+  #     else:
+  #       return set(world.prepare_sparql("""SELECT ?c { ?c (rdfs:subClassOf|owl:equivalentClass|^owl:equivalentClass)*/rdfs:subClassOf ?? . FILTER(ISIRI(?c)) }""").execute_flat((Class,)))
+    
   def _fill_ancestors(Class, s, include_self, include_constructs):
     if include_self:
       if not Class in s:
@@ -314,7 +336,7 @@ class EntityClass(type):
         if isinstance(parent, EntityClass):
           if not parent in s:
             parent._fill_ancestors(s, True, False)
-        
+            
   def _fill_descendants(Class, s, include_self, only_loaded, world, onto):
     if include_self:
       s.add(Class)
@@ -343,9 +365,6 @@ class EntityClass(type):
         world = owlready2.default_world
         
       for x, in world.graph.db.execute(
-#    """SELECT q1.s FROM objs q1 WHERE q1.s > 0 and q1.p = ? AND q1.o = ?
-#EXCEPT SELECT q2.s FROM objs q2 WHERE q2.p = ? and q2.o != ? and q2.o > 0""",
-#          (rdf_type, owl_class, rdfs_subclassof, owl_thing)):
           """SELECT q1.s FROM objs q1 WHERE q1.p=? AND q1.o=? AND ((q1.s > 0))
     AND (SELECT 1 FROM objs q2 INDEXED BY index_objs_sp
     WHERE q2.s=q1.s AND q2.p=? AND ((q2.o > 0) AND q2.o != ?)) IS NULL""",
@@ -464,14 +483,23 @@ class ThingClass(EntityClass):
     new._set(new2)
   disjoint_unions = property(get_disjoint_unions, set_disjoint_unions)
   
-      
+  
+  # def instances(Class, world = None):
+  #   if Class.namespace.world is owl_world:
+  #     import owlready2
+  #     world = (world or owlready2.default_world).world
+  #     if Class is Thing: return world.individuals()
+  #     return world.search(type = Class)
+  #   return Class.namespace.world.search(type = Class)
+  
   def instances(Class, world = None):
     if Class.namespace.world is owl_world:
       import owlready2
       world = (world or owlready2.default_world).world
       if Class is Thing: return world.individuals()
-      return world.search(type = Class)
-    return Class.namespace.world.search(type = Class)
+    else:
+      world = Class.namespace.world
+    return world.prepare_sparql("""SELECT DISTINCT ?i { ?i a/(rdfs:subClassOf|owl:equivalentClass|^owl:equivalentClass)* ?? . }""").execute_flat((Class,))
   
   def direct_instances(Class, world = None):
     if Class.namespace.world is owl_world:
